<?php

namespace Litematrimony\Reference\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litematrimony\Reference\Models\Visit;

class VisitPolicy
{

    /**
     * Determine if the given user can view the visit.
     *
     * @param UserPolicy $user
     * @param Visit $visit
     *
     * @return bool
     */
    public function view(UserPolicy $user, Visit $visit)
    {
        if ($user->canDo('reference.visit.view') && $user->isAdmin()) {
            return true;
        }

        return $visit->user_id == user_id() && $visit->user_type == user_type();
    }

    /**
     * Determine if the given user can create a visit.
     *
     * @param UserPolicy $user
     * @param Visit $visit
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('reference.visit.create');
    }

    /**
     * Determine if the given user can update the given visit.
     *
     * @param UserPolicy $user
     * @param Visit $visit
     *
     * @return bool
     */
    public function update(UserPolicy $user, Visit $visit)
    {
        if ($user->canDo('reference.visit.edit') && $user->isAdmin()) {
            return true;
        }

        return $visit->user_id == user_id() && $visit->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given visit.
     *
     * @param UserPolicy $user
     * @param Visit $visit
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Visit $visit)
    {
        return $visit->user_id == user_id() && $visit->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given visit.
     *
     * @param UserPolicy $user
     * @param Visit $visit
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Visit $visit)
    {
        if ($user->canDo('reference.visit.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given visit.
     *
     * @param UserPolicy $user
     * @param Visit $visit
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Visit $visit)
    {
        if ($user->canDo('reference.visit.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
