<?php

namespace Litematrimony\Reference\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litematrimony\Reference\Models\Reference;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litematrimony\Reference\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/reference/visit/*')) {
            Route::bind('visit', function ($visit) {
                $visitrepo = $this->app->make('Litematrimony\Reference\Interfaces\VisitRepositoryInterface');
                return $visitrepo->findorNew($visit);
            });
        }
        if (Request::is('*/reference/shortlist/*')) {
            Route::bind('shortlist', function ($shortlist) {
                $shortlistrepo = $this->app->make('Litematrimony\Reference\Interfaces\ShortlistRepositoryInterface');
                return $shortlistrepo->findorNew($shortlist);
            });
        }
        if (Request::is('*/reference/request/*')) {
            Route::bind('request', function ($request) {
                $requestrepo = $this->app->make('Litematrimony\Reference\Interfaces\RequestRepositoryInterface');
                return $requestrepo->findorNew($request);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
